@@ -12,11 +12,11 @@ define({
 	"Editor": "Editor",
 	"switchEditor": "Switch Editor",
 	"Fetching": "Fetching: ${0}",
-	"confirmUnsavedChanges": "There are unsaved changes. Do you still want to navigate away?",
+	"confirmUnsavedChanges": "There are unsaved changes in the current file.  If you navigate to a different file, you will lose your changes.  \n\nDo you want to navigate away?",
 	"searchFilesCommand": "Quick Search...",
 	"searchFiles": "Quick Search in ${0}",
 	"searchTerm": "Enter search term:",
-	"unsavedChanges": "There are unsaved changes.",
+	"unsavedChanges": "There are unsaved changes in current file, you can't navigate away without saving it.",
 	"unsavedAutoSaveChanges": "Please stay on the page until Auto Save is complete.",
 	"Save": "Save",
 	"Saved": "Saved",
